local Pipeline(image, version, compiler, depinstall) = {
  kind: "pipeline",
  type: "docker",
  name: image+"-"+version+"-"+compiler,
  platform: {
    os: "linux",
    arch: "amd64"
  },
  steps: [
    {
      name: "build",
      image: image+":"+version,
      commands: [
        depinstall+" make "+compiler,
        "make clean",
        "make CC="+compiler+" CFLAGS=\"-Wall -Werror -Wno-unknown-warning-option -Wno-unknown-pragmas -Wno-packed-bitfield-compat\""
      ]
    }
  ]
};

local AptPipeline(image, version, compiler) = Pipeline(image, version, compiler, "apt update && DEBIAN_FRONTEND=noninteractive apt install -y");

local PacManPipeline(image, version, compiler) = Pipeline(image, version, compiler, "pacman -Syy && pacman --noconfirm -S");

local ApkPipeline(image, version, compiler) = Pipeline(image, version, compiler, "apk add --update gcc musl-dev");

local YumPipeline(image, version, compiler) = Pipeline(image, version, compiler, "yum install -y");

local XbpsPipeline(image, version, compiler) = Pipeline(image, version, compiler, "xbps-install -Sy");

[
  AptPipeline("ubuntu", "20.04", "gcc"),
  AptPipeline("ubuntu", "20.04", "clang"),
  AptPipeline("ubuntu", "18.04", "gcc"),
  AptPipeline("ubuntu", "18.04", "clang"),

  AptPipeline("debian", "buster", "gcc"),
  AptPipeline("debian", "buster", "clang"),
  AptPipeline("debian", "stretch", "gcc"),
  AptPipeline("debian", "stretch", "clang"),

  YumPipeline("fedora", "latest", "gcc"),
  YumPipeline("fedora", "latest", "clang"),

  PacManPipeline("archlinux", "latest", "gcc"),
  PacManPipeline("archlinux", "latest", "clang"),

  ApkPipeline("alpine", "latest", "gcc"),
  ApkPipeline("alpine", "latest", "clang"),

  XbpsPipeline("voidlinux/voidlinux", "latest", "gcc"),
  XbpsPipeline("voidlinux/voidlinux", "latest", "clang")
]